@@ -107,7 +107,7 @@ const Auth: React.FC<any> = ({ children }) => {
       switch (data.payload.event) {
         case 'signIn':
           AmplifyAuth.currentUserInfo()
-            .then(user => setRuntimeContext({ ...runtimeContext, user }))
+            .then(user => setRuntimeContext((prevRuntimeContext: any) => ({ ...prevRuntimeContext, user })))
             .catch(e => console.error(e));
           break;
         case 'signOut':
@@ -115,7 +115,7 @@ const Auth: React.FC<any> = ({ children }) => {
           break;
       }
     });
-  }, [runtimeContext]);
+  }, []);
 
   const AuthWrapper: React.FC<any> = useCallback(({ children: _children }) => runtimeContext.userPoolId ?
     <ThemeProvider theme={theme}>
